@@ -10,10 +10,10 @@
  * version 2 of the License, or (at your option) any later version.
  *
  * \par
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * \par
  * You should have received a copy of the GNU Lesser General Public
@@ -87,7 +87,7 @@
 char* CDS_Control  = ":60606/Server0/CDS_control";
 int ReadoutMode = 2; // this should be picked up from the settings.... 0-> JPG; 1->RAW; 2 -> Thumbnails
 char* cameraShutterSpeed = "B"; // //placeholder to store the value of the shutterspeed set in camera; "B" is for bulb.
-int captureDuration = 10; //placeholder to store the value of the bulb shot this should be taken as input. note that my primary goal is in fact to perform bulb captures. but this should be extended for sure to take Shutter Speed capture as set in camera 
+int captureDuration = 10; //placeholder to store the value of the bulb shot this should be taken as input. note that my primary goal is in fact to perform bulb captures. but this should be extended for sure to take Shutter Speed capture as set in camera
 
 static int NumberPix(Camera *camera);
 static char* loadCmd (Camera *camera,char* cmd);
@@ -120,7 +120,7 @@ struct _CameraPrivateLibrary {
 
 
 static int
-camera_exit (Camera *camera, GPContext *context) 
+camera_exit (Camera *camera, GPContext *context)
 {
 	if (camera->pl->udpsocket > 0) {
 		close (camera->pl->udpsocket);
@@ -138,9 +138,8 @@ camera_capture_preview (Camera *camera, CameraFile *file, GPContext *context)
 	GPPortInfo      	info;
 	int			i, start, end, tries;
 
-	switchToRecMode (camera);
-
 	if (!camera->pl->liveview) {
+		switchToRecMode (camera);
 		loadCmd(camera,"cam.cgi?mode=startstream&value=49199");
 		camera->pl->liveview = 1;
 		if (camera->pl->udpsocket <= 0) {
@@ -265,7 +264,7 @@ delete_all_func (CameraFilesystem *fs, const char *folder, void *data,
 
 /**
  * Get the file info here and write it to space provided by caller.
- * 
+ *
  * \param info Space provided by caller in which file info is written.
  *
  * This function is a CameraFilesystem method.
@@ -282,7 +281,7 @@ get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	return GP_OK;
 }
 
-
+#if 0
 static int
 set_info_func (CameraFilesystem *fs, const char *folder, const char *file,
 	       CameraFileInfo info, void *data, GPContext *context)
@@ -293,7 +292,7 @@ set_info_func (CameraFilesystem *fs, const char *folder, const char *file,
 
 	return GP_OK;
 }
-
+#endif
 
 static int
 folder_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
@@ -351,7 +350,7 @@ int
 storage_info_func (CameraFilesystem *fs,
 		CameraStorageInformation **storageinformations,
 		int *nrofstorageinformations, void *data,
-		GPContext *context) 
+		GPContext *context)
 {
 	/*Camera *camera = data;*/
 
@@ -380,7 +379,7 @@ write_callback(char *contents, size_t size, size_t nmemb, void *userp)
 	LumixMemoryBuffer	*lmb = userp;
 
 	oldsize = lmb->size;
-	/* 1 additionaly byte for 0x00 */
+	/* 1 additionally byte for 0x00 */
 	lmb->data = realloc(lmb->data, lmb->size+realsize+1);
 	lmb->size += realsize;
 	lmb->data[lmb->size] = 0x00;
@@ -419,7 +418,7 @@ loadCmd (Camera *camera,char* cmd) {
 		fprintf(stderr, "curl_easy_perform() failed: %s\n", curl_easy_strerror(res));
 		return NULL;
 	} else {
-		/* read the XML that is now in Buffer*/ 
+		/* read the XML that is now in Buffer*/
 		GP_LOG_D("result %s\n", lmb.data);
 
 		/* <?xml version="1.0" encoding="UTF-8"?> <camrply><result>ok</result></camrply> */
@@ -438,12 +437,13 @@ switchToPlayMode(Camera *camera) {
 	return loadCmd(camera,"cam.cgi?mode=camcmd&value=playmode");
 }
 
-
+#if 0
 static void Set_ISO(Camera *camera,const char * ISOValue) {
 	char buf[200];
 	sprintf(buf, "?mode=setsetting&type=iso&value=%s",ISOValue);
 	loadCmd(camera,buf);
 }
+#endif
 
 static char*
 generic_setting_getter(Camera *camera, char *type) {
@@ -565,26 +565,31 @@ Get_ExTeleConv(Camera *camera) {
 	return generic_setting_getter(camera,"ex_tele_conv");
 }
 
+#if 0
 static char*
 Get_Capability(Camera *camera) {
 	return loadCmd(camera,"cam.cgi?mode=getinfo&type=capability");
 }
+#endif
 
 static char*
 Get_Lens(Camera *camera) {
 	return loadCmd(camera,"cam.cgi?mode=getinfo&type=lens");
 }
 
+#if 0
 static char*
 Get_AllMenu(Camera *camera) {
 	return loadCmd(camera,"cam.cgi?mode=getinfo&type=allmenu");
 }
+#endif
 
+#if 0
 static char*
 Get_CurMenu(Camera *camera) {
 	return loadCmd(camera,"cam.cgi?mode=getinfo&type=curmenu");
 }
-
+#endif
 
 static void Set_ShutterSpeed(Camera *camera,const char* SpeedValue) {
 	char buf[200];
@@ -635,46 +640,44 @@ static void stopMovie(Camera *camera) {
 	loadCmd(camera,"cam.cgi?mode=camcmd&value=video_recstop");
 }
 
+#if 0
 static void zoomIn(Camera *camera) {
 	loadCmd(camera,"cam.cgi?mode=camcmd&value=tele-fast");
 }
+#endif
 
+#if 0
 static void zoomOut(Camera *camera) {
 	loadCmd(camera,"cam.cgi?mode=camcmd&value=wide-fast");
 }
+#endif
 
+#if 0
 static void zoomStop(Camera *camera) {
 	loadCmd(camera,"cam.cgi?mode=camcmd&value=zoomstop");
 }
+#endif
 
+#if 0
 static void focusIn(Camera *camera) {
 	loadCmd(camera,"cam.cgi?mode=camctrl&type=focus&value=tele-fast");
 }
+#endif
 
+#if 0
 static void focusOut(Camera *camera) {
 	loadCmd(camera,"cam.cgi?mode=camctrl&type=focus&value=wide-fast");
 }
+#endif
 
 /*
 
-this is the XML sample to be parsed by the function below   NumberPix() 
+this is the XML sample to be parsed by the function below   NumberPix()
 <?xml version="1.0" encoding="UTF-8"?>
 <camrply><result>ok</result><current_position>341</current_position><total_content_number>372</total_content_number><content_number>342</content_number></camrply>
 
 
 */
-static int
-strend(const char *s, const char *t)
-{
-    size_t ls = strlen(s); // find length of s
-    size_t lt = strlen(t); // find length of t
-    if (ls >= lt)  // check if t can fit in s
-    {
-        // point s to where t should start and compare the strings from there
-        return (0 == memcmp(t, s + (ls - lt), lt));
-    }
-    return 0; // t was longer than s
-}
 
 static int
 NumberPix(Camera *camera) {
@@ -682,9 +685,9 @@ NumberPix(Camera *camera) {
 	int		numpics = 0;
 	char		*temp = loadCmd(camera,"cam.cgi?mode=get_content_info");
 	xmlDocPtr	doc = xmlParseDoc((unsigned char*) temp);
-	xmlNodePtr	cur = NULL; 
+	xmlNodePtr	cur = NULL;
 
-	cur = xmlDocGetRootElement(doc);   
+	cur = xmlDocGetRootElement(doc);
 
 	if (cur == NULL) {
 		GP_LOG_E("empty xml result document");
@@ -724,7 +727,7 @@ NumberPix(Camera *camera) {
 	return numpics;
 }
 
-/*utility function to creat a SOAP envelope for the lumix cam */  
+/*utility function to creat a SOAP envelope for the lumix cam */
 static char*
 SoapEnvelop(int start, int num){
 	static char  Envelop[1000];
@@ -833,7 +836,7 @@ GetPixRange(Camera *camera, int start, int num) {
 		}
 		xchar = xmlNodeGetContent (output);
 		GP_LOG_D("content of %s is %s", output->name, xchar);
-	/* 
+	/*
 
 	<DIDL-Lite xmlns="urn:schemas-upnp-org:metadata-1-0/DIDL-Lite/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:upnp="urn:schemas-upnp-org:metadata-1-0/upnp/">
 		<item id="1030822" parentID="0" restricted="0">
@@ -966,8 +969,7 @@ Raw:
 
 				GP_LOG_D("\t child content %s", xmlNodeGetContent(child));
 
-				/* FIXME: perhaps shorten match? */
-				if (strstr((char*)attrcontent,"PANASONIC.COM_PN=CAM_AVC_MP4_HP_2160_30P_AAC")) {
+				if (strstr((char*)attrcontent,"PANASONIC.COM_PN=CAM_AVC_MP4")) {
 					camera->pl->pics[i].url_movie = strdup((char*)xmlNodeGetContent(child));
 				}
 				// http-get:*:application/octet-stream;PANASONIC.COM_PN=CAM_RAW
@@ -1103,11 +1105,12 @@ static struct aperturemap {
 };
 
 static int
-camera_config_get (Camera *camera, CameraWidget **window, GPContext *context) 
+camera_config_get (Camera *camera, CameraWidget **window, GPContext *context)
 {
         CameraWidget	*widget,*section;
-        int		ret, i, valset;
-	char		*val, *curval;
+        int		valset;
+        unsigned int 	i;
+	char		*val;
 
 	switchToRecMode (camera);
 
@@ -1266,12 +1269,13 @@ camera_config_get (Camera *camera, CameraWidget **window, GPContext *context)
 }
 
 static int
-camera_config_set (Camera *camera, CameraWidget *window, GPContext *context) 
+camera_config_set (Camera *camera, CameraWidget *window, GPContext *context)
 {
 	CameraWidget	*widget;
 	char		*val;
 	char		buf[50];
-	int		i, ret;
+	int		ret;
+	unsigned int	i;
 
 	if ((GP_OK == gp_widget_get_child_by_name(window, "zoom", &widget)) && gp_widget_changed (widget)) {
 		if (GP_OK != (ret = gp_widget_get_value (widget, &val)))
@@ -1377,16 +1381,29 @@ camera_config_set (Camera *camera, CameraWidget *window, GPContext *context)
 }
 
 
+#if 0
+static int
+strend(const char *s, const char *t)
+{
+    size_t ls = strlen(s); // find length of s
+    size_t lt = strlen(t); // find length of t
+    if (ls >= lt)  // check if t can fit in s
+    {
+        // point s to where t should start and compare the strings from there
+        return (0 == memcmp(t, s + (ls - lt), lt));
+    }
+    return 0; // t was longer than s
+}
 
 static char*
 processNode(xmlTextReaderPtr reader) {
-	char* ret =""; 
+	char* ret ="";
 	char* lookupImgtag="";
 
 	switch (ReadoutMode) {
 	case 0 : //'jpg
 		lookupImgtag = "CAM_RAW_JPG";
-	break; 
+	break;
 	case 1 :// 'raw
 		lookupImgtag = "CAM_RAW";
 	break;
@@ -1395,7 +1412,7 @@ processNode(xmlTextReaderPtr reader) {
 	break;
 	}
 
-    const xmlChar *name, *value;
+    const xmlChar *name;
 
     name = xmlTextReaderConstName(reader);
     if (name == NULL)
@@ -1532,31 +1549,27 @@ ReadImageFromCamera(Camera *camera, CameraFilePath *path, GPContext *context) {
 	char			*image;
 	long			nRead;
 	LumixMemoryBuffer	lmb;
-	char			*xmlimageName;
-	xmlDocPtr		doc; /* the resulting document tree */
 	int			ret;
 	char			* imageURL="";
 	xmlTextReaderPtr	reader;
 
 	switchToPlayMode (camera);
 
-	reader = xmlReaderForDoc((xmlChar*)GetPixRange(camera,NumberPix(camera)-1,1), NULL,"noname.xml", XML_PARSE_DTDATTR |  /* default DTD attributes */ XML_PARSE_NOENT); 
+	reader = xmlReaderForDoc((xmlChar*)GetPixRange(camera,NumberPix(camera)-1,1), NULL,"noname.xml", XML_PARSE_DTDATTR |  /* default DTD attributes */ XML_PARSE_NOENT);
 	ret = xmlTextReaderRead(reader);
 	while (ret == 1) {
-	    imageURL = processNode(reader); 
+	    imageURL = processNode(reader);
             if (strlen(imageURL))
-		break; 
+		break;
             ret = xmlTextReaderRead(reader);
 	}
 
-	GP_DEBUG("the image URL is  %s\n",imageURL); 
+	GP_DEBUG("the image URL is  %s\n",imageURL);
 	image = strdup(imageURL);
 	nRead = 0;
 	CURL* imageUrl;
 	imageUrl = curl_easy_init();
 	CURLcode res;
-	double bytesread = 0;
-	char filename[100];
 	long http_response;
 	int ret_val=0;
 
@@ -1599,7 +1612,7 @@ ReadImageFromCamera(Camera *camera, CameraFilePath *path, GPContext *context) {
 	strcpy(path->folder, "/");
 	return add_objectid_and_upload (camera, path, context, lmb.data, lmb.size);
 }
-
+#endif
 
 /**
 * Capture an image and tell libgphoto2 where to find it by filling
@@ -1635,8 +1648,8 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path, GP
 		return ret;
 
 
-	if (strcmp(cameraShutterSpeed, "B")!=0) {  
-		sleep(captureDuration); // Sleep for the duration to simulate exposure, if this is in Bulb mode 
+	if (strcmp(cameraShutterSpeed, "B")!=0) {
+		sleep(captureDuration); // Sleep for the duration to simulate exposure, if this is in Bulb mode
 	} else {
 		sleep(3);
 	}
@@ -1668,7 +1681,7 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path, GP
 }
 
 /**
-* Fill out the summary with textual information about the current 
+* Fill out the summary with textual information about the current
 * state of the camera (like pictures taken, etc.).
 *
 * This function is a method of the Camera object.
@@ -1682,7 +1695,7 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *context)
 
 /**
 * Return the camera drivers manual.
-* If you would like to tell the user some information about how 
+* If you would like to tell the user some information about how
 * to use the camera or the driver, this is the place to do.
 *
 * This function is a method of the Camera object.
@@ -1731,10 +1744,9 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename, C
 	int		i;
 	CURLcode	res;
 	CURL		*imageUrl;
-	double		bytesread = 0;
 	long		http_response;
 	int		ret_val = 0;
-	long			nRead;
+	long			nRead = 0;
 	LumixMemoryBuffer	lmb;
 	const char	*url;
 
@@ -1829,8 +1841,8 @@ int camera_abilities (CameraAbilitiesList *list) {
 	a.status	= GP_DRIVER_STATUS_EXPERIMENTAL;
 	a.port		= GP_PORT_IP;
 	a.operations	= GP_CAPTURE_IMAGE| GP_OPERATION_CAPTURE_VIDEO | GP_OPERATION_CONFIG;
-	a.file_operations = GP_FILE_OPERATION_PREVIEW  ; 
-	/* it should be possible to browse and DL images the files using the ReadImageFromCamera() function but for now lets keep it simple*/ 
+	a.file_operations = GP_FILE_OPERATION_PREVIEW  ;
+	/* it should be possible to browse and DL images the files using the ReadImageFromCamera() function but for now lets keep it simple*/
 	a.folder_operations = GP_FOLDER_OPERATION_NONE;
 	return gp_abilities_list_append(list, a);
 }
@@ -1865,7 +1877,7 @@ CameraFilesystemFuncs fsfuncs = {
 * This is a camlib API function.
 */
 int
-camera_init (Camera *camera, GPContext *context) 
+camera_init (Camera *camera, GPContext *context)
 {
 	GPPortInfo      info;
 	int		ret;
@@ -1907,8 +1919,6 @@ camera_init (Camera *camera, GPContext *context)
 	if (switchToRecMode (camera) != NULL) {
 		int numpix;
 
-		Set_quality(camera,"raw_fine");
-
 		switchToPlayMode (camera);
 
 		numpix = NumberPix(camera);
@@ -1920,7 +1930,7 @@ camera_init (Camera *camera, GPContext *context)
 
 
 int
-camera_id (CameraText *id) 
+camera_id (CameraText *id)
 {
 	strcpy(id->text, "Lumix Wifi");
 
