@@ -1,4 +1,4 @@
-var gphoto2-port-result_8c =
+var gphoto2_port_result_8c =
 [
     [ "_", "gphoto2-port-result_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
     [ "bindtextdomain", "gphoto2-port-result_8c.html#add6dfc1077058ff26d79cdb18099d58a", null ],
