@@ -1,11 +1,12 @@
 var NAVTREEINDEX1 =
 {
+"gphoto2-camera_8h.html#a7dc2b5ed66b61b881caf7436cb05ded0":[2,0,1,1,38],
+"gphoto2-camera_8h.html#a87bb8878064d7c4a98f1be7cedf7fd3c":[2,0,1,1,58],
 "gphoto2-camera_8h.html#a8fa6903e3bf0ab26edc4e915512aa44f":[2,0,1,1,28],
 "gphoto2-camera_8h.html#a95f595a6d9bfe68d99419a0087363f89":[2,0,1,1,56],
 "gphoto2-camera_8h.html#a969c10fd16501f62f0e3a276d237764a":[2,0,1,1,47],
 "gphoto2-camera_8h.html#aa22be0b9b3018082174d0f7c8ecd2e26":[2,0,1,1,50],
 "gphoto2-camera_8h.html#aa3dd64d491735a55bcab15d41b9113c3":[2,0,1,1,40],
-"gphoto2-camera_8h.html#aa93f252a9f1957bd563e759bc7debac2":[2,0,1,1,22],
 "gphoto2-camera_8h.html#aac1b7a2a855f989bdbdd255fdf04a46c":[2,0,1,1,24],
 "gphoto2-camera_8h.html#aae2a7f4fc07d99b4524fa29f76975b11":[2,0,1,1,6],
 "gphoto2-camera_8h.html#aaf28826f8251bfde0f1cbc07fae1bf50":[2,0,1,1,10],
@@ -16,7 +17,6 @@ var NAVTREEINDEX1 =
 "gphoto2-camera_8h.html#ac97991bc04586bd093569b1b00d07821":[2,0,1,1,5],
 "gphoto2-camera_8h.html#accaa70d614800dac941e543187c9712d":[2,0,1,1,29],
 "gphoto2-camera_8h.html#ad1c8f7fc0c347f7eb3d443a06ab10370":[2,0,1,1,11],
-"gphoto2-camera_8h.html#ad3b42d26bfbfe0fb0b9671c84c50f138":[2,0,1,1,20],
 "gphoto2-camera_8h.html#ad89d6ee1c35f5ee399e89ecaeac6bd61":[2,0,1,1,54],
 "gphoto2-camera_8h.html#adb3e8a4b8b179b6319fc90b6d2105fb1":[2,0,1,1,13],
 "gphoto2-camera_8h.html#adda54321b1947b711d345936041f80c7":[2,0,1,1,33],
@@ -50,37 +50,37 @@ var NAVTREEINDEX1 =
 "gphoto2-context_8c.html#afefd086439808e0ea31fe982cf2bf742":[2,0,2,10,4],
 "gphoto2-context_8h.html":[2,0,1,2],
 "gphoto2-context_8h.html#a0fd357aa949525dd1a3a2bdb404366cf":[2,0,1,2,16],
+"gphoto2-context_8h.html#a10082cd168c37576b45be37c3ca5c76f":[2,0,1,2,5],
 "gphoto2-context_8h.html#a118cc634d4288bc3722391691bf89f0c":[2,0,1,2,20],
+"gphoto2-context_8h.html#a16b20e80d9a7baefb6297fb802eeb291":[2,0,1,2,1],
 "gphoto2-context_8h.html#a1decda483ec848e9cfd0ce68fb35ba82":[2,0,1,2,12],
-"gphoto2-context_8h.html#a1eea319168183e636b1daa1f47d50ba3":[2,0,1,2,3],
+"gphoto2-context_8h.html#a21179514caccfdc96f16c9cb3b0616ce":[2,0,1,2,4],
 "gphoto2-context_8h.html#a2af604b145886e65cfb39b6eca75fe7e":[2,0,1,2,27],
 "gphoto2-context_8h.html#a3ecfdf82f972b15f8d4feb26a9d25b92":[2,0,1,2,0],
+"gphoto2-context_8h.html#a44ebbe423abd916b269721bd5eea08a1":[2,0,1,2,7],
 "gphoto2-context_8h.html#a47bb3df49a3b08e69600fe8e67d4dfbf":[2,0,1,2,19],
-"gphoto2-context_8h.html#a49f9a7add15882035b805f445ca52443":[2,0,1,2,5],
+"gphoto2-context_8h.html#a4e2f435e5e9445dec6acbf8075df4748":[2,0,1,2,6],
 "gphoto2-context_8h.html#a51bc910dfc03c967e3c6ba03b43fbfb3":[2,0,1,2,22],
-"gphoto2-context_8h.html#a69933b78a78e29e448df5e3eeec9131e":[2,0,1,2,6],
+"gphoto2-context_8h.html#a68c27346ca3a74c582cc23cbdf2e8ad4":[2,0,1,2,3],
 "gphoto2-context_8h.html#a6a87ac8f4beeff86f0d247623b39a5fe":[2,0,1,2,25],
 "gphoto2-context_8h.html#a6d241a0d2941e08a4d918cd923b7d9f3":[2,0,1,2,17],
-"gphoto2-context_8h.html#a72219eda743a898485d0abb074c5ea51":[2,0,1,2,7],
-"gphoto2-context_8h.html#a7ca4c4ee3adfc94fc6fe2fa932279f59":[2,0,1,2,4],
-"gphoto2-context_8h.html#a8270084178bf37b5530a7401b7d7eba1":[2,0,1,2,1],
+"gphoto2-context_8h.html#a80691acdd4fc7d4123177a64b1858e22":[2,0,1,2,10],
+"gphoto2-context_8h.html#a861ed01af8a3c7506c3f17477e847eb7":[2,0,1,2,8],
 "gphoto2-context_8h.html#a8ee292247dd4512ec0f71b62bd24fcd1":[2,0,1,2,26],
 "gphoto2-context_8h.html#a925d07de0bb8cfc37acc5891b11bc1a5":[2,0,1,2,23],
 "gphoto2-context_8h.html#a941ca9159c54542bbdb3fc6f165f2851":[2,0,1,2,21],
 "gphoto2-context_8h.html#a986c79c9bd39aef8b7f4b5129738ac20":[2,0,1,2,24],
-"gphoto2-context_8h.html#aa118e47f41dc74c15b9e137a4a64045d":[2,0,1,2,10],
+"gphoto2-context_8h.html#aa9d5709d4b016b0b82228ce9513cacbd":[2,0,1,2,9],
 "gphoto2-context_8h.html#aaf988fc2b9e09b4054ac5988b683ed52":[2,0,1,2,15],
 "gphoto2-context_8h.html#ab8786f91f991473182ef47d8abf2fd1d":[2,0,1,2,28],
 "gphoto2-context_8h.html#ac015a1ed8c349b1bda9b0f652904d0ac":[2,0,1,2,30],
 "gphoto2-context_8h.html#ac30a859efe417aa671cfa32275940d87":[2,0,1,2,29],
+"gphoto2-context_8h.html#ae0b20374ca00dfd87267aede0d898284":[2,0,1,2,2],
 "gphoto2-context_8h.html#ae3ccc9d5a652ca165b4a0d22cf6e493f":[2,0,1,2,11],
 "gphoto2-context_8h.html#ae3ccc9d5a652ca165b4a0d22cf6e493fadde53439fb2bad49c0922a5719394963":[2,0,1,2,11,0],
 "gphoto2-context_8h.html#ae3ccc9d5a652ca165b4a0d22cf6e493fafadd72ed8d05a4692bac36e6f6170a59":[2,0,1,2,11,1],
 "gphoto2-context_8h.html#aec0c2be0a43adeec13fd6c6aed5d3bf0":[2,0,1,2,13],
-"gphoto2-context_8h.html#aecc9fa3aecd2a3ab19c7e702c59cea98":[2,0,1,2,9],
 "gphoto2-context_8h.html#aed9bdc97988854ae81a7cc57e94a064e":[2,0,1,2,18],
-"gphoto2-context_8h.html#aefce8d3118d24bed2eabbd9f1c2e3ba8":[2,0,1,2,2],
-"gphoto2-context_8h.html#af3c296969e76d37581d02810fe9f99f7":[2,0,1,2,8],
 "gphoto2-context_8h.html#afefd086439808e0ea31fe982cf2bf742":[2,0,1,2,14],
 "gphoto2-context_8h_source.html":[2,0,1,2],
 "gphoto2-endian_8h_source.html":[2,0,2,11],
@@ -145,7 +145,6 @@ var NAVTREEINDEX1 =
 "gphoto2-file_8h.html#ab0c9c2ff2ef54f2ead016ed5a82f895f":[2,0,1,3,49],
 "gphoto2-file_8h.html#ab1601098b75b7e6f0eaa91f9105fceec":[2,0,1,3,23],
 "gphoto2-file_8h.html#ab2fc202bdab8503ab5dca38357dff494":[2,0,1,3,51],
-"gphoto2-file_8h.html#ab5554e64015b042cc297a461be90d6c4":[2,0,1,3,28],
 "gphoto2-file_8h.html#ab9c078f6915a3186c90ff81cc52da898":[2,0,1,3,41],
 "gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69":[2,0,1,3,30],
 "gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a533cccf7871c3ddfe182425f0b1a06f9":[2,0,1,3,30,0],
@@ -174,12 +173,12 @@ var NAVTREEINDEX1 =
 "gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842af8d7ad7cfc3baaa5135ca835d4e388c7":[2,0,1,3,29,2],
 "gphoto2-file_8h.html#ae6f2318d561ce3ff3a37a1145a0e1de6":[2,0,1,3,20],
 "gphoto2-file_8h.html#af0d1d638d7a58ae9591be458eeb13c72":[2,0,1,3,42],
+"gphoto2-file_8h.html#afd151a6d5fb1c1664924ae52ce7fedcd":[2,0,1,3,28],
 "gphoto2-file_8h.html#afe87b1e2f9df858f3737bb0d603a0d6e":[2,0,1,3,32],
 "gphoto2-file_8h_source.html":[2,0,1,3],
 "gphoto2-filesys_8c.html":[2,0,2,13],
 "gphoto2-filesys_8c.html#a083ea3fd7f794f6de09c1c51ba142572":[2,0,2,13,29],
 "gphoto2-filesys_8c.html#a08fa6e05d77adce0b6be853c226dedaa":[2,0,2,13,27],
-"gphoto2-filesys_8c.html#a09a92d2b9ed9744765bb3216f986a794":[2,0,2,13,20],
 "gphoto2-filesys_8c.html#a0e785e85f4a199ee87dfd7604ad8d45a":[2,0,2,13,26],
 "gphoto2-filesys_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5":[2,0,2,13,11],
 "gphoto2-filesys_8c.html#a2cd5449536c57828b6873e635b51de72":[2,0,2,13,7],
@@ -204,13 +203,14 @@ var NAVTREEINDEX1 =
 "gphoto2-filesys_8c.html#a7fdf2e5f1c7fda4b0f7f58f45a33c71c":[2,0,2,13,22],
 "gphoto2-filesys_8c.html#a83b8be0887dede025766d25e2bb884c6":[2,0,2,13,13],
 "gphoto2-filesys_8c.html#a8fb447618db946a9e2a596d9ea18763f":[2,0,2,13,4],
+"gphoto2-filesys_8c.html#a91fd5cf4334c4b4c5aebc6f52333ccbf":[2,0,2,13,19],
 "gphoto2-filesys_8c.html#a97c3a1cb9996eb8319d232023209bf19":[2,0,2,13,32],
+"gphoto2-filesys_8c.html#a9cb6a3a83e8a6cc6ad93b6422e707d8a":[2,0,2,13,20],
 "gphoto2-filesys_8c.html#aa6cd62861b01c157efcdf25dd2753576":[2,0,2,13,25],
 "gphoto2-filesys_8c.html#aafe39aadfe2259eb5bc3d3de0dd864cc":[2,0,2,13,21],
 "gphoto2-filesys_8c.html#ab22748e14f4e4d0492c4ddeeec557e70":[2,0,2,13,35],
 "gphoto2-filesys_8c.html#ac58c62bed856f6b143aaa776d74b5705":[2,0,2,13,30],
 "gphoto2-filesys_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07":[2,0,2,13,12],
-"gphoto2-filesys_8c.html#ad6a4885b641b284f22ef55ad3ec8aac2":[2,0,2,13,19],
 "gphoto2-filesys_8c.html#add6dfc1077058ff26d79cdb18099d58a":[2,0,2,13,5],
 "gphoto2-filesys_8c.html#ae1e4bab15af84be9873bbd14b383da25":[2,0,2,13,38],
 "gphoto2-filesys_8c.html#ae6106ac2f70f59b50525a8de870ec25b":[2,0,2,13,33],
@@ -237,7 +237,10 @@ var NAVTREEINDEX1 =
 "gphoto2-filesys_8h.html#a42d72c58efd503dc56e35b38877fe06d":[2,0,1,4,19],
 "gphoto2-filesys_8h.html#a4d1424f4d45018dc892a2da792822f0c":[2,0,1,4,33],
 "gphoto2-filesys_8h.html#a4e4ea8548673cc56c465ee447dd916f3":[2,0,1,4,54],
+"gphoto2-filesys_8h.html#a5521a0eba8d4f7706dfd506109ef5ec4":[2,0,1,4,6],
 "gphoto2-filesys_8h.html#a57f7b7038489eadd5a78787d6cfe8d66":[2,0,1,4,50],
+"gphoto2-filesys_8h.html#a5b6ad64bc00efa2cf7e67c6564f6b323":[2,0,1,4,7],
+"gphoto2-filesys_8h.html#a5db5df72a4392ada3038917a307ae77c":[2,0,1,4,9],
 "gphoto2-filesys_8h.html#a5e8cab7c2e27696f6299860669f77268":[2,0,1,4,14],
 "gphoto2-filesys_8h.html#a6b6fc659abe86a1724fe6600d112931f":[2,0,1,4,32],
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907":[2,0,1,4,23],
@@ -246,8 +249,5 @@ var NAVTREEINDEX1 =
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a259e66be4884ad572ca319e0c510d52f":[2,0,1,4,23,1],
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a6603c2d07d8d87bfc5378f99f0869665":[2,0,1,4,23,6],
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a70c192de7c121febde90af7e117c0eed":[2,0,1,4,23,0],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7c19dc619e18629df027df1f8aaa1035":[2,0,1,4,23,8],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7f0cc4ba19d9f92f2e8e12de6580f47b":[2,0,1,4,23,2],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9277302e076066219975e49bbc574600":[2,0,1,4,23,7],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9ed3048a35c2f6a59d6e89e52f24b1a5":[2,0,1,4,23,5]
+"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7c19dc619e18629df027df1f8aaa1035":[2,0,1,4,23,8]
 };
